summaryrefslogtreecommitdiffstats
path: root/chrome/browser/metrics/chrome_metrics_service_client.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/metrics/chrome_metrics_service_client.h')
-rw-r--r--chrome/browser/metrics/chrome_metrics_service_client.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/chrome/browser/metrics/chrome_metrics_service_client.h b/chrome/browser/metrics/chrome_metrics_service_client.h
index 34723b4..b991f61 100644
--- a/chrome/browser/metrics/chrome_metrics_service_client.h
+++ b/chrome/browser/metrics/chrome_metrics_service_client.h
@@ -83,9 +83,12 @@ class ChromeMetricsServiceClient
// Completes the two-phase initialization of ChromeMetricsServiceClient.
void Initialize();
// Callback that continues the init task by loading plugin information.
void OnInitTaskGotHardwareClass();
+ // Callback that continues the init task by loading plugin information.
+ void OnInitTaskGotBluetoothAdapter();
+
// Called after the Plugin init task has been completed that continues the
// init task by launching a task to gather Google Update statistics.
void OnInitTaskGotPluginInfo();
@@ -83,9 +83,12 @@ class ChromeMetricsServiceClient
// Completes the two-phase initialization of ChromeMetricsServiceClient.
void Initialize();
- // Callback that continues the init task by loading plugin information.
+ // Callback that continues the init task by getting a Bluetooth Adapter.
void OnInitTaskGotHardwareClass();